@@ -23,7 +23,7 @@ $Params::Check::VERBOSE = 1;
 use vars qw[@ISA $VERSION];
 
 @ISA     = qw[CPANPLUS::Internals];
-$VERSION = $CPANPLUS::Internals::VERSION;
+$VERSION = "0.9136";
 
 ### mark that we're running under CPANPLUS to spawned processes
 $ENV{'PERL5_CPANPLUS_IS_RUNNING'} = $$;
@@ -36,7 +36,7 @@ $ENV{'PERL5_CPANPLUS_IS_VERSION'} = __PACKAGE__->VERSION;
 
 =head1 NAME
 
-CPANPLUS::Backend
+CPANPLUS::Backend - programmer's interface to CPANPLUS
 
 =head1 SYNOPSIS
 
@@ -397,7 +397,7 @@ for my $func (qw[fetch extract install readme files distributions]) {
 
         return CPANPLUS::Backend::RV->new(
                     function    => $func,
-                    ok          => !$flag,
+                    ok          => ( !$flag ? 1 : 0 ),
                     rv          => $href,
                     args        => \%hash,
                 );
@@ -418,6 +418,8 @@ C<parse_module>;
 
 =item Text-Bastardize
 
+=item Text/Bastardize.pm
+
 =item Text-Bastardize-1.06
 
 =item AYRNIEU/Text-Bastardize
@@ -570,6 +572,16 @@ sub parse_module {
         return $modobj;
     }
 
+    # Stolen from cpanminus to support 'Module/Install.pm'
+    # type input
+    if ( ( my $tmpmod = $mod ) =~ s/\.pm$//i ) {
+        my ($volume, $dirs, $file) = File::Spec->splitpath( $tmpmod );
+        $tmpmod = join '::', grep { $_ } File::Spec->splitdir( $dirs ), $file;
+        ### perhaps we can find it in the module tree?
+        my $maybe = $self->module_tree( $tmpmod );
+        return $maybe if IS_MODOBJ->( module => $maybe );
+    }
+
     ### perhaps we can find it's a third party module?
     {   my $modobj = CPANPLUS::Module::Fake->new(
                         module  => $mod,
@@ -1100,7 +1112,7 @@ sub autobundle {
     print $fh <<EOF;
 package $name;
 
-\$VERSION = '0.01';
+\$VERSION = "0.9136";
 
 1;
 
