@@ -1,15 +1,16 @@
 package CPANPLUS::Module::Fake;
 
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Module;
 use CPANPLUS::Module::Author::Fake;
 use CPANPLUS::Internals;
 
 use strict;
-use vars            qw[@ISA];
+use vars            qw[@ISA $VERSION];
 use Params::Check   qw[check];
 
+$VERSION = "0.9136";
 @ISA = qw[CPANPLUS::Module];
 $Params::Check::VERBOSE = 1;
 
@@ -17,7 +18,7 @@ $Params::Check::VERBOSE = 1;
 
 =head1 NAME
 
-CPANPLUS::Module::Fake
+CPANPLUS::Module::Fake - fake module object for internal use
 
 =head1 SYNOPSIS
 
@@ -49,9 +50,9 @@ are required.
 sub new {
     my $class = shift;
     my %hash  = @_;
-    
+
     local $Params::Check::ALLOW_UNKNOWN = 1;
-    
+
     my $tmpl = {
         module  => { required => 1 },
         path    => { required => 1 },
@@ -59,22 +60,22 @@ sub new {
         _id     => { default => CPANPLUS::Internals->_last_id },
         author  => { default => '' },
     };
-    
+
     my $args = check( $tmpl, \%hash ) or return;
-    
-    $args->{author} ||= CPANPLUS::Module::Author::Fake->new( 
+
+    $args->{author} ||= CPANPLUS::Module::Author::Fake->new(
                                                         _id => $args->{_id} );
-    
+
     my $obj = CPANPLUS::Module->new( %$args ) or return;
-    
+
     unless( $obj->_id ) {
         error(loc("No '%1' specified -- No CPANPLUS object associated!",'_id'));
         return;
-    }        
-    
+    }
+
     ### rebless object ###
-    return bless $obj, $class;                                   
-}    
+    return bless $obj, $class;
+}
 
 1;
 
@@ -83,4 +84,4 @@ sub new {
 # c-basic-offset: 4
 # indent-tabs-mode: nil
 # End:
-# vim: expandtab shiftwidth=4:    
+# vim: expandtab shiftwidth=4:
